@@ -126,8 +126,7 @@ class CRM_ACL_BAO_ACL extends CRM_ACL_DAO_ACL {
       'GroupContact' => CRM_Contact_DAO_GroupContact::getTableName(),
     );
 
-    $session = CRM_Core_Session::singleton();
-    $contact_id = $session->get('userID');
+    $contact_id = CRM_Core_Session::getLoggedInContactID();
 
     $where = " {$t['ACL']}.operation = '" . CRM_Utils_Type::escape($operation, 'String') . "'";
 
@@ -722,55 +721,15 @@ SELECT count( a.id )
     return ($count) ? TRUE : FALSE;
   }
 
-  /**
-   * Build a join and where part for a query
-   *
-   * @param int $contactId
-   * @return array - the first key is join part of the query and the second key is the where part of the query
-   */
-  public static function buildAcl($contactId) {
-    // If there is no $contactId passed return empty ACL join and where clause
-    if (empty($contactId)) {
-      return array('', '');
-    }
-
-    $tables = array();
-    $whereTables = array();
-    $whereClause = CRM_ACL_BAO_ACL::whereClause(CRM_Core_Permission::VIEW, $tables, $whereTables, $contactId, TRUE);
-    if (strlen($whereClause)) {
-      $whereClause = " AND (" . $whereClause . ")";
-    }
-
-    $join = "";
-    foreach ($whereTables as $name => $value) {
-      if (!$value) {
-        continue;
-      }
-      if ($value != 1) {
-        // if there is already a join statement in value, use value itself
-        if (strpos($value, 'JOIN')) {
-          $join .= " $value ";
-        }
-        continue;
-      }
-    }
-
-    return array(
-      $join,
-      $whereClause,
-    );
-  }
-
   /**
    * @param $type
    * @param $tables
    * @param $whereTables
    * @param int $contactID
-   * @param bool $strictReturn If there is no where clause build for ACL
    *
    * @return null|string
    */
-  public static function whereClause($type, &$tables, &$whereTables, $contactID = NULL, $strictReturn = FALSE) {
+  public static function whereClause($type, &$tables, &$whereTables, $contactID = NULL) {
     $acls = CRM_ACL_BAO_Cache::build($contactID);
 
     $whereClause = NULL;
@@ -880,7 +839,7 @@ SELECT g.*
     // call the hook to get additional whereClauses
     CRM_Utils_Hook::aclWhereClause($type, $tables, $whereTables, $contactID, $whereClause);
 
-    if (empty($whereClause) && !$strictReturn) {
+    if (empty($whereClause)) {
       $whereClause = ' ( 0 ) ';
     }
 
@@ -903,6 +862,13 @@ SELECT g.*
     $allGroups = NULL,
     $includedGroups = NULL
   ) {
+    $userCacheKey = "{$contactID}_{$type}_{$tableName}_" . CRM_Core_Config::domainID() . '_' . md5(implode(',', array_merge((array) $allGroups, (array) $includedGroups)));
+    if (empty(Civi::$statics[__CLASS__]['permissioned_groups'])) {
+      Civi::$statics[__CLASS__]['permissioned_groups'] = array();
+    }
+    if (!empty(Civi::$statics[__CLASS__]['permissioned_groups'][$userCacheKey])) {
+      return Civi::$statics[__CLASS__]['permissioned_groups'][$userCacheKey];
+    }
 
     $acls = CRM_ACL_BAO_Cache::build($contactID);
 
@@ -953,9 +919,25 @@ ORDER BY a.object_id
     ) {
       $ids = $includedGroups;
     }
+    if ($contactID) {
+      $groupWhere = '';
+      if (!empty($allGroups)) {
+        $groupWhere = " AND id IN (" . implode(',', array_keys($allGroups)) . ")";
+      }
+      // Contacts create hidden groups from search results. They should be able to retrieve their own.
+      $ownHiddenGroupsList = CRM_Core_DAO::singleValueQuery("
+        SELECT GROUP_CONCAT(id) FROM civicrm_group WHERE is_hidden =1 AND created_id = $contactID
+        $groupWhere
+      ");
+      if ($ownHiddenGroupsList) {
+        $ownHiddenGroups = explode(',', $ownHiddenGroupsList);
+        $ids = array_merge((array) $ids, $ownHiddenGroups);
+      }
+
+    }
 
     CRM_Utils_Hook::aclGroup($type, $contactID, $tableName, $allGroups, $ids);
-
+    Civi::$statics[__CLASS__]['permissioned_groups'][$userCacheKey] = $ids;
     return $ids;
   }
 
