@@ -110,7 +110,7 @@ class CRM_Admin_Form_LocationType extends CRM_Admin_Form {
 
     if ($params['is_default']) {
       $query = "UPDATE civicrm_location_type SET is_default = 0";
-      CRM_Core_DAO::executeQuery($query, CRM_Core_DAO::$_nullArray);
+      CRM_Core_DAO::executeQuery($query);
     }
 
     if ($this->_action & CRM_Core_Action::UPDATE) {
