@@ -36,6 +36,13 @@
  */
 class CRM_Admin_Form_OptionGroup extends CRM_Admin_Form {
 
+  /**
+   * Explicitly declare the entity api name.
+   */
+  public function getDefaultEntity() {
+    return 'OptionGroup';
+  }
+
   /**
    * Build the form object.
    */
@@ -71,6 +78,8 @@ class CRM_Admin_Form_OptionGroup extends CRM_Admin_Form {
       CRM_Core_DAO::getAttribute('CRM_Core_DAO_OptionGroup', 'description')
     );
 
+    $this->addSelect('data_type', array('options' => CRM_Utils_Type::dataTypes()), TRUE);
+
     $element = $this->add('checkbox', 'is_active', ts('Enabled?'));
     if ($this->_action & CRM_Core_Action::UPDATE) {
       if (in_array($this->_values['name'], array(
