@@ -215,7 +215,7 @@ class CRM_Admin_Form_PaymentProcessorType extends CRM_Admin_Form {
     if (!empty($values['is_default'])) {
       $query = "
 UPDATE civicrm_payment_processor SET is_default = 0";
-      CRM_Core_DAO::executeQuery($query, CRM_Core_DAO::$_nullArray);
+      CRM_Core_DAO::executeQuery($query);
     }
 
     $dao = new CRM_Financial_DAO_PaymentProcessorType();
