@@ -37,7 +37,7 @@
 class CRM_Admin_Form_Preferences extends CRM_Core_Form {
   protected $_system = FALSE;
   protected $_contactID = NULL;
-  protected $_action = NULL;
+  public $_action = NULL;
 
   protected $_checkbox = NULL;
 
@@ -174,6 +174,10 @@ class CRM_Admin_Form_Preferences extends CRM_Core_Form {
               $this->addRadio($fieldName, $fieldValue['title'], $options, NULL, '&nbsp;&nbsp;');
               break;
 
+            case 'YesNo':
+              $this->addRadio($fieldName, $fieldValue['title'], array(0 => 'No', 1 => 'Yes'), NULL, '&nbsp;&nbsp;');
+              break;
+
             case 'checkboxes':
               $options = array_flip(CRM_Core_OptionGroup::values($fieldName, FALSE, FALSE, TRUE));
               $newOptions = array();
@@ -269,6 +273,7 @@ class CRM_Admin_Form_Preferences extends CRM_Core_Form {
           case 'text':
           case 'select':
           case 'radio':
+          case 'YesNo':
           case 'entity_reference':
             $this->_config->$settingName = CRM_Utils_Array::value($settingName, $this->_params);
             break;
