@@ -37,6 +37,14 @@
 class CRM_Admin_Form_Preferences_Contribute extends CRM_Admin_Form_Preferences {
   protected $_settings = array(
     'cvv_backoffice_required' => CRM_Core_BAO_Setting::CONTRIBUTE_PREFERENCES_NAME,
+    'acl_financial_type' => CRM_Core_BAO_Setting::CONTRIBUTE_PREFERENCES_NAME,
+    'always_post_to_accounts_receivable' => CRM_Core_BAO_Setting::CONTRIBUTE_PREFERENCES_NAME,
+    'deferred_revenue_enabled' => CRM_Core_BAO_Setting::CONTRIBUTE_PREFERENCES_NAME,
+    'default_invoice_page' => CRM_Core_BAO_Setting::CONTRIBUTE_PREFERENCES_NAME,
+    'financial_account_bal_enable' => CRM_Core_BAO_Setting::CONTRIBUTE_PREFERENCES_NAME,
+    'fiscalYearStart' => CRM_Core_BAO_Setting::LOCALIZATION_PREFERENCES_NAME,
+    'prior_financial_period' => CRM_Core_BAO_Setting::CONTRIBUTE_PREFERENCES_NAME,
+    'invoicing' => CRM_Core_BAO_Setting::CONTRIBUTE_PREFERENCES_NAME,
   );
 
   /**
@@ -118,30 +126,77 @@ class CRM_Admin_Form_Preferences_Contribute extends CRM_Admin_Form_Preferences {
    * Build the form object.
    */
   public function buildQuickForm() {
-    //CRM-16691: Changes made related to settings of 'CVV'.
+    $htmlFields = array();
     foreach ($this->_settings as $setting => $group) {
       $settingMetaData = civicrm_api3('setting', 'getfields', array('name' => $setting));
       $props = $settingMetaData['values'][$setting];
       if (isset($props['quick_form_type'])) {
         $add = 'add' . $props['quick_form_type'];
         if ($add == 'addElement') {
-          $this->$add(
-            $props['html_type'],
-            $setting,
-            ts($props['title']),
-            CRM_Utils_Array::value($props['html_type'] == 'select' ? 'option_values' : 'html_attributes', $props, array()),
-            $props['html_type'] == 'select' ? CRM_Utils_Array::value('html_attributes', $props) : NULL
-          );
+          if (in_array($props['html_type'], array('checkbox', 'textarea'))) {
+            $this->add($props['html_type'],
+              $setting,
+              $props['title']
+            );
+          }
+          else {
+            if ($props['html_type'] == 'select') {
+              $functionName = CRM_Utils_Array::value('name', CRM_Utils_Array::value('pseudoconstant', $props));
+              if ($functionName) {
+                $props['option_values'] = array('' => ts('- select -')) + CRM_Contribute_PseudoConstant::$functionName();
+              }
+            }
+            $this->$add(
+              $props['html_type'],
+              $setting,
+              ts($props['title']),
+              CRM_Utils_Array::value($props['html_type'] == 'select' ? 'option_values' : 'html_attributes', $props, array()),
+              $props['html_type'] == 'select' ? CRM_Utils_Array::value('html_attributes', $props) : NULL
+            );
+          }
+        }
+        elseif ($add == 'addMonthDay') {
+          $this->add('date', $setting, ts($props['title']), CRM_Core_SelectValues::date(NULL, 'M d'));
+        }
+        elseif ($add == 'addDate') {
+          $this->addDate($setting, ts($props['title']), FALSE, array('formatType' => $props['type']));
         }
         else {
           $this->$add($setting, ts($props['title']));
         }
       }
-      $this->assign("{$setting}_description", ts($props['description']));
+      $htmlFields[$setting] = ts($props['description']);
     }
-    $this->add('checkbox', 'invoicing', ts('Enable Tax and Invoicing'));
-    $this->add('checkbox', 'acl_financial_type', ts('Enable Access Control by Financial Type'));
+    $this->assign('htmlFields', $htmlFields);
     parent::buildQuickForm();
+    $this->addFormRule(array('CRM_Admin_Form_Preferences_Contribute', 'formRule'), $this);
+  }
+
+  /**
+   * Global validation rules for the form.
+   *
+   * @param array $values
+   *   posted values of the form
+   * @param $files
+   * @param $self
+   *
+   * @return array
+   *   list of errors to be posted back to the form
+   */
+  public static function formRule($values, $files, $self) {
+    $errors = array();
+    if (CRM_Utils_Array::value('deferred_revenue_enabled', $values)) {
+      $errorMessage = CRM_Financial_BAO_FinancialAccount::validateTogglingDeferredRevenue();
+      if ($errorMessage) {
+        // Since the error msg is too long and
+        // takes the whole space to display inline
+        // therefore setting blank text to highlight the field
+        // setting actual error msg to _qf_default to show in pop-up screen
+        $errors['deferred_revenue_enabled'] = ' ';
+        $errors['_qf_default'] = $errorMessage;
+      }
+    }
+    return $errors;
   }
 
   /**
@@ -152,16 +207,19 @@ class CRM_Admin_Form_Preferences_Contribute extends CRM_Admin_Form_Preferences {
   public function setDefaultValues() {
     $defaults = Civi::settings()->get('contribution_invoice_settings');
     //CRM-16691: Changes made related to settings of 'CVV'.
-    foreach ($this->_settings as $setting => $group) {
+    foreach (array('cvv_backoffice_required') as $setting) {
       $settingMetaData = civicrm_api3('setting', 'getfields', array('name' => $setting));
       $defaults[$setting] = civicrm_api3('setting', 'getvalue',
         array(
           'name' => $setting,
-          'group' => $group,
+          'group' => CRM_Core_BAO_Setting::CONTRIBUTE_PREFERENCES_NAME,
           'default_value' => CRM_Utils_Array::value('default', $settingMetaData['values'][$setting]),
         )
       );
     }
+    $defaults['fiscalYearStart'] = Civi::settings()->get('fiscalYearStart');
+    $period = CRM_Contribute_BAO_Contribution::checkContributeSettings('prior_financial_period');
+    $this->assign('priorFinancialPeriod', $period);
     return $defaults;
   }
 
@@ -174,6 +232,7 @@ class CRM_Admin_Form_Preferences_Contribute extends CRM_Admin_Form_Preferences {
     unset($params['qfKey']);
     unset($params['entryURL']);
     Civi::settings()->set('contribution_invoice_settings', $params);
+    Civi::settings()->set('fiscalYearStart', $params['fiscalYearStart']);
 
     // to set default value for 'Invoices / Credit Notes' checkbox on display preferences
     $values = CRM_Core_BAO_Setting::getItem("CiviCRM Preferences");
@@ -190,14 +249,16 @@ class CRM_Admin_Form_Preferences_Contribute extends CRM_Admin_Form_Preferences {
     else {
       $setting = explode(CRM_Core_DAO::VALUE_SEPARATOR, substr($values['user_dashboard_options'], 1, -1));
       $invoiceKey = array_search($setKey, $setting);
-      unset($setting[$invoiceKey]);
+      if ($invoiceKey !== FALSE) {
+        unset($setting[$invoiceKey]);
+      }
       $settingName = CRM_Core_DAO::VALUE_SEPARATOR .
         implode(CRM_Core_DAO::VALUE_SEPARATOR, array_values($setting)) .
         CRM_Core_DAO::VALUE_SEPARATOR;
       Civi::settings()->set('user_dashboard_options', $settingName);
     }
     //CRM-16691: Changes made related to settings of 'CVV'.
-    $settings = array_intersect_key($params, $this->_settings);
+    $settings = array_intersect_key($params, array('cvv_backoffice_required' => 1));
     $result = civicrm_api3('setting', 'create', $settings);
     CRM_Core_Session::setStatus(ts('Your changes have been saved.'), ts('Changes Saved'), "success");
   }
