@@ -3,7 +3,7 @@
  +--------------------------------------------------------------------+
  | CiviCRM version 4.7                                                |
  +--------------------------------------------------------------------+
- | Copyright CiviCRM LLC (c) 2004-2015                                |
+ | Copyright CiviCRM LLC (c) 2004-2016                                |
  +--------------------------------------------------------------------+
  | This file is a part of CiviCRM.                                    |
  |                                                                    |
@@ -28,7 +28,7 @@
 /**
  *
  * @package CRM
- * @copyright CiviCRM LLC (c) 2004-2015
+ * @copyright CiviCRM LLC (c) 2004-2016
  */
 
 /**
@@ -106,7 +106,7 @@ class CRM_Admin_Form_ScheduleReminders extends CRM_Admin_Form {
       'text',
       'title',
       ts('Title'),
-      array('size' => 45, 'maxlength' => 128),
+      CRM_Core_DAO::getAttribute('CRM_Core_DAO_ActionSchedule', 'title'),
       TRUE
     );
 
@@ -309,11 +309,15 @@ class CRM_Admin_Form_ScheduleReminders extends CRM_Admin_Form {
     }
 
     if (!empty($fields['is_active']) &&
-      CRM_Utils_Array::value('mode', $fields) == 'SMS' &&
       CRM_Utils_System::isNull($fields['subject'])
     ) {
       $errors['subject'] = ts('Subject is a required field.');
     }
+    if (!empty($fields['is_active']) &&
+      CRM_Utils_System::isNull(trim(strip_tags($fields['html_message'])))
+    ) {
+      $errors['html_message'] = ts('The HTML message is a required field.');
+    }
 
     if (empty($self->_context) && CRM_Utils_System::isNull(CRM_Utils_Array::value(1, $fields['entity']))) {
       $errors['entity'] = ts('Please select entity value');
