@@ -46,7 +46,7 @@ class CRM_Admin_Page_APIExplorer extends CRM_Core_Page {
       ->addScriptFile('civicrm', 'templates/CRM/Admin/Page/APIExplorer.js')
       ->addScriptFile('civicrm', 'bower_components/google-code-prettify/bin/prettify.min.js', 99)
       ->addStyleFile('civicrm', 'bower_components/google-code-prettify/bin/prettify.min.css', 99)
-      ->addVars('explorer', array('max_joins' => \Civi\API\SelectQuery::MAX_JOINS));
+      ->addVars('explorer', array('max_joins' => \Civi\API\Api3SelectQuery::MAX_JOINS));
 
     $this->assign('operators', CRM_Core_DAO::acceptedSQLOperators());
 
