@@ -41,7 +41,7 @@ class CRM_Campaign_Form_Campaign extends CRM_Core_Form {
    *
    * @var int
    */
-  protected $_action;
+  public $_action;
 
   /**
    * Context
