@@ -107,11 +107,6 @@ class CRM_Contact_BAO_Group extends CRM_Contact_DAO_Group {
     $query = "DELETE FROM civicrm_acl_entity_role where entity_table = 'civicrm_group' AND entity_id = %1";
     CRM_Core_DAO::executeQuery($query, $params);
 
-    if (Civi::settings()->get('is_enabled')) {
-      // clear any descendant groups cache if exists
-      CRM_Core_BAO_Cache::deleteGroup('descendant groups for an org');
-    }
-
     // delete from group table
     $group = new CRM_Contact_DAO_Group();
     $group->id = $id;
@@ -135,7 +130,7 @@ class CRM_Contact_BAO_Group extends CRM_Contact_DAO_Group {
    * @param int $id
    */
   public static function getGroupContacts($id) {
-    $params = array(array('group', 'IN', array($id => 1), 0, 0));
+    $params = array(array('group', 'IN', array(1 => $id), 0, 0));
     list($contacts, $_) = CRM_Contact_BAO_Query::apiQuery($params, array('contact_id'));
     return $contacts;
   }
@@ -193,14 +188,16 @@ class CRM_Contact_BAO_Group extends CRM_Contact_DAO_Group {
    *
    * @param int $groupID
    * @param bool $useCache
+   * @param int $limit
+   *   Number to limit to (or 0 for unlimited).
    *
    * @return array
    *   this array contains the list of members for this group id
    */
-  public static function &getMember($groupID, $useCache = TRUE) {
+  public static function getMember($groupID, $useCache = TRUE, $limit = 0) {
     $params = array(array('group', '=', $groupID, 0, 0));
     $returnProperties = array('contact_id');
-    list($contacts, $_) = CRM_Contact_BAO_Query::apiQuery($params, $returnProperties, NULL, NULL, 0, 0, $useCache);
+    list($contacts) = CRM_Contact_BAO_Query::apiQuery($params, $returnProperties, NULL, NULL, 0, $limit, $useCache);
 
     $aMembers = array();
     foreach ($contacts as $contact) {
@@ -344,7 +341,7 @@ class CRM_Contact_BAO_Group extends CRM_Contact_DAO_Group {
    * @return CRM_Contact_BAO_Group|NULL
    *   The new group BAO (if created)
    */
-  public static function &create(&$params) {
+  public static function create(&$params) {
 
     if (!empty($params['id'])) {
       CRM_Utils_Hook::pre('edit', 'Group', $params['id'], $params);
@@ -363,9 +360,12 @@ class CRM_Contact_BAO_Group extends CRM_Contact_DAO_Group {
     if (isset($params['group_type'])) {
       if (is_array($params['group_type'])) {
         $params['group_type'] = CRM_Core_DAO::VALUE_SEPARATOR . implode(CRM_Core_DAO::VALUE_SEPARATOR,
-            array_keys($params['group_type'])
+            $params['group_type']
           ) . CRM_Core_DAO::VALUE_SEPARATOR;
       }
+      else {
+        $params['group_type'] = CRM_Core_DAO::VALUE_SEPARATOR . $params['group_type'] . CRM_Core_DAO::VALUE_SEPARATOR;
+      }
     }
     else {
       $params['group_type'] = NULL;
@@ -382,6 +382,14 @@ class CRM_Contact_BAO_Group extends CRM_Contact_DAO_Group {
       $params['modified_id'] = $cid;
     }
 
+    // CRM-19068.
+    // Validate parents parameter when creating group.
+    if (!empty($params['parents'])) {
+      $parents = is_array($params['parents']) ? array_keys($params['parents']) : (array) $params['parents'];
+      foreach ($parents as $parent) {
+        CRM_Utils_Type::validate($parent, 'Integer');
+      }
+    }
     $group = new CRM_Contact_BAO_Group();
     $group->copyValues($params);
     //@todo very hacky fix for the fact this function wants to receive 'parents' as an array further down but
@@ -443,9 +451,6 @@ class CRM_Contact_BAO_Group extends CRM_Contact_DAO_Group {
         }
       }
 
-      // clear any descendant groups cache if exists
-      $finalGroups = CRM_Core_BAO_Cache::deleteGroup('descendant groups for an org');
-
       // this is always required, since we don't know when a
       // parent group is removed
       CRM_Contact_BAO_GroupNestingCache::update();
@@ -458,12 +463,12 @@ class CRM_Contact_BAO_Group extends CRM_Contact_DAO_Group {
     }
 
     if (!empty($params['organization_id'])) {
-      $groupOrg = array();
       $groupOrg = $params;
       $groupOrg['group_id'] = $group->id;
       CRM_Contact_BAO_GroupOrganization::add($groupOrg);
     }
 
+    CRM_Utils_System::flushCache();
     CRM_Contact_BAO_GroupContactCache::add($group->id);
 
     if (!empty($params['id'])) {
@@ -652,9 +657,13 @@ class CRM_Contact_BAO_Group extends CRM_Contact_DAO_Group {
       //save the mapping for search builder
       if (!$ssId) {
         //save record in mapping table
-        $temp = array();
-        $mappingParams = array('mapping_type' => 'Search Builder');
-        $mapping = CRM_Core_BAO_Mapping::add($mappingParams, $temp);
+        $mappingParams = array(
+          'mapping_type_id' => CRM_Core_OptionGroup::getValue('mapping_type',
+            'Search Builder',
+            'name'
+          ),
+        );
+        $mapping = CRM_Core_BAO_Mapping::add($mappingParams);
         $mappingId = $mapping->id;
       }
       else {
@@ -701,6 +710,20 @@ class CRM_Contact_BAO_Group extends CRM_Contact_DAO_Group {
       $smartGroupId = $smartGroup->id;
     }
 
+    // Update mapping with the name and description of the hidden smart group.
+    if ($mappingId) {
+      $mappingParams = array(
+        'id' => $mappingId,
+        'name' => CRM_Core_DAO::getFieldValue('CRM_Contact_DAO_Group', $smartGroupId, 'name', 'id'),
+        'description' => CRM_Core_DAO::getFieldValue('CRM_Contact_DAO_Group', $smartGroupId, 'description', 'id'),
+        'mapping_type_id' => CRM_Core_OptionGroup::getValue('mapping_type',
+          'Search Builder',
+          'name'
+        ),
+      );
+      CRM_Core_BAO_Mapping::add($mappingParams);
+    }
+
     return array($smartGroupId, $ssId);
   }
 
@@ -755,7 +778,7 @@ class CRM_Contact_BAO_Group extends CRM_Contact_DAO_Group {
         $value['class'] = array_diff($value['class'], array('crm-row-parent'));
       }
       $group['DT_RowId'] = 'row_' . $value['id'];
-      if (!$params['parentsOnly']) {
+      if (empty($params['parentsOnly'])) {
         foreach ($value['class'] as $id => $class) {
           if ($class == 'crm-group-parent') {
             unset($value['class'][$id]);
@@ -788,8 +811,8 @@ class CRM_Contact_BAO_Group extends CRM_Contact_DAO_Group {
 
     $groupsDT = array();
     $groupsDT['data'] = $groupList;
-    $groupsDT['recordsTotal'] = $params['total'];
-    $groupsDT['recordsFiltered'] = $params['total'];
+    $groupsDT['recordsTotal'] = !empty($params['total']) ? $params['total'] : NULL;
+    $groupsDT['recordsFiltered'] = !empty($params['total']) ? $params['total'] : NULL;
 
     return $groupsDT;
   }
@@ -809,6 +832,7 @@ class CRM_Contact_BAO_Group extends CRM_Contact_DAO_Group {
 
     //$this->pagerAToZ( $whereClause, $params );
 
+    $limit = "";
     if (!empty($params['rowCount']) &&
       $params['rowCount'] > 0
     ) {
@@ -837,7 +861,7 @@ class CRM_Contact_BAO_Group extends CRM_Contact_DAO_Group {
                                ON contact.id = gOrg.organization_id ";
 
       //get the Organization ID
-      $orgID = CRM_Utils_Request::retrieve('oid', 'Positive', CRM_Core_DAO::$_nullObject);
+      $orgID = CRM_Utils_Request::retrieve('oid', 'Positive');
       if ($orgID) {
         $where = " AND gOrg.organization_id = {$orgID}";
       }
@@ -852,7 +876,6 @@ class CRM_Contact_BAO_Group extends CRM_Contact_DAO_Group {
           ON createdBy.id = groups.created_id
         {$from}
         WHERE $whereClause {$where}
-        GROUP BY groups.id
         {$orderBy}
         {$limit}";
 
@@ -1320,4 +1343,20 @@ WHERE {$whereClause}";
     return CRM_Utils_PagerAToZ::getAToZBar($dao, $this->_sortByCharacter, TRUE);
   }
 
+  /**
+   * Assign Test Value.
+   *
+   * @param string $fieldName
+   * @param array $fieldDef
+   * @param int $counter
+   */
+  protected function assignTestValue($fieldName, &$fieldDef, $counter) {
+    if ($fieldName == 'children' || $fieldName == 'parents') {
+      $this->{$fieldName} = "NULL";
+    }
+    else {
+      parent::assignTestValues($fieldName, $fieldDef, $counter);
+    }
+  }
+
 }
