@@ -51,6 +51,9 @@ class CRM_Contact_Form_DedupeFind extends CRM_Admin_Form {
     $groupList = array('' => ts('- All Contacts -')) + CRM_Core_PseudoConstant::nestedGroup();
 
     $this->add('select', 'group_id', ts('Select Group'), $groupList, FALSE, array('class' => 'crm-select2 huge'));
+    if (Civi::settings()->get('dedupe_default_limit')) {
+      $this->add('text', 'limit', ts('No of contacts to find matches for '));
+    }
     $this->addButtons(array(
         array(
           'type' => 'next',
@@ -69,6 +72,7 @@ class CRM_Contact_Form_DedupeFind extends CRM_Admin_Form {
   }
 
   public function setDefaultValues() {
+    $this->_defaults['limit'] = Civi::settings()->get('dedupe_default_limit');
     return $this->_defaults;
   }
 
@@ -82,11 +86,13 @@ class CRM_Contact_Form_DedupeFind extends CRM_Admin_Form {
       CRM_Utils_System::redirect(CRM_Utils_System::url('civicrm/contact/deduperules', 'reset=1'));
       return;
     }
+    $url = CRM_Utils_System::url('civicrm/contact/dedupefind', "reset=1&action=update&rgid={$this->rgid}");
     if ($values['group_id']) {
-      $url = CRM_Utils_System::url('civicrm/contact/dedupefind', "reset=1&action=update&rgid={$this->rgid}&gid={$values['group_id']}");
+      $url .= "&gid={$values['group_id']}";
     }
-    else {
-      $url = CRM_Utils_System::url('civicrm/contact/dedupefind', "reset=1&action=update&rgid={$this->rgid}");
+
+    if (!empty($values['limit'])) {
+      $url .= '&limit=' . $values['limit'];
     }
 
     CRM_Utils_System::redirect($url);
