@@ -138,6 +138,10 @@ class CRM_Contact_Form_Edit_CommunicationPreferences {
         );
       }
     }
+
+    if (array_key_exists('preferred_mail_format', $fields) && empty($fields['preferred_mail_format'])) {
+      $errors['preferred_mail_format'] = ts('Please select an email format preferred by this contact.');
+    }
     return empty($errors) ? TRUE : $errors;
   }
 
@@ -168,6 +172,9 @@ class CRM_Contact_Form_Edit_CommunicationPreferences {
     if (empty($defaults['preferred_mail_format'])) {
       $defaults['preferred_mail_format'] = 'Both';
     }
+    else {
+      $defaults['preferred_mail_format'] = array_search($defaults['preferred_mail_format'], CRM_Core_SelectValues::pmf());
+    }
 
     //set default from greeting types CRM-4575, CRM-9739
     if ($form->_action & CRM_Core_Action::ADD) {
