@@ -131,10 +131,17 @@ class CRM_Contact_Form_Relationship extends CRM_Core_Form {
     $this->_display_name_a = CRM_Core_DAO::getFieldValue('CRM_Contact_DAO_Contact', $this->_contactId, 'display_name');
 
     $this->assign('display_name_a', $this->_display_name_a);
+    //get the relationship values.
+    $this->_values = array();
+    if ($this->_relationshipId) {
+      $params = array('id' => $this->_relationshipId);
+      CRM_Core_DAO::commonRetrieve('CRM_Contact_DAO_Relationship', $params, $this->_values);
+    }
 
     // Check for permissions
     if (in_array($this->_action, array(CRM_Core_Action::ADD, CRM_Core_Action::UPDATE, CRM_Core_Action::DELETE))) {
-      if (!CRM_Contact_BAO_Contact_Permission::allow($this->_contactId, CRM_Core_Permission::EDIT)) {
+      if (!CRM_Contact_BAO_Contact_Permission::allow($this->_contactId, CRM_Core_Permission::EDIT)
+        && !CRM_Contact_BAO_Contact_Permission::allow($this->_values['contact_id_b'], CRM_Core_Permission::EDIT)) {
         CRM_Core_Error::statusBounce(ts('You do not have the necessary permission to edit this contact.'));
       }
     }
@@ -160,13 +167,6 @@ class CRM_Contact_Form_Relationship extends CRM_Core_Form {
 
     $this->_caseId = CRM_Utils_Request::retrieve('caseID', 'Integer', $this);
 
-    //get the relationship values.
-    $this->_values = array();
-    if ($this->_relationshipId) {
-      $params = array('id' => $this->_relationshipId);
-      CRM_Core_DAO::commonRetrieve('CRM_Contact_DAO_Relationship', $params, $this->_values);
-    }
-
     if (!$this->_rtypeId) {
       $params = CRM_Utils_Request::exportValues();
       if (isset($params['relationship_type_id'])) {
