@@ -42,9 +42,7 @@ class CRM_Contact_Form_Search_Custom_Sample extends CRM_Contact_Form_Search_Cust
     parent::__construct($formValues);
 
     if (!isset($formValues['state_province_id'])) {
-      $this->_stateID = CRM_Utils_Request::retrieve('stateID', 'Integer',
-        CRM_Core_DAO::$_nullObject
-      );
+      $this->_stateID = CRM_Utils_Request::retrieve('stateID', 'Integer');
       if ($this->_stateID) {
         $formValues['state_province_id'] = $this->_stateID;
       }
@@ -77,7 +75,7 @@ class CRM_Contact_Form_Search_Custom_Sample extends CRM_Contact_Form_Search_Cust
     /**
      * You can define a custom title for the search form
      */
-    $this->setTitle('My Search Title');
+    $this->setTitle(ts('My Search Title'));
 
     /**
      * if you are using the standard template, this array tells the template what elements
