@@ -36,6 +36,13 @@
  */
 class CRM_Contact_Import_Form_Preview extends CRM_Import_Form_Preview {
 
+  /**
+   * Whether USPS validation should be disabled during import.
+   *
+   * @var bool
+   */
+  protected $_disableUSPS;
+
   /**
    * Set variables up before form is built.
    */
@@ -47,6 +54,7 @@ class CRM_Contact_Import_Form_Preview extends CRM_Import_Form_Preview {
     $conflictRowCount = $this->get('conflictRowCount');
     $mismatchCount = $this->get('unMatchCount');
     $columnNames = $this->get('columnNames');
+    $this->_disableUSPS = $this->get('disableUSPS');
 
     //assign column names
     $this->assign('columnNames', $columnNames);
@@ -136,6 +144,14 @@ class CRM_Contact_Import_Form_Preview extends CRM_Import_Form_Preview {
   public function buildQuickForm() {
     $this->addElement('text', 'newGroupName', ts('Name for new group'), CRM_Core_DAO::getAttribute('CRM_Contact_DAO_Group', 'title'));
     $this->addElement('text', 'newGroupDesc', ts('Description of new group'));
+    $groupTypes = CRM_Core_OptionGroup::values('group_type', TRUE);
+    if (!empty($groupTypes)) {
+      $this->addCheckBox('newGroupType',
+        ts('Group Type'),
+        $groupTypes,
+        NULL, NULL, NULL, NULL, '&nbsp;&nbsp;&nbsp;'
+      );
+    }
 
     $groups = $this->get('groups');
 
@@ -255,6 +271,7 @@ class CRM_Contact_Import_Form_Preview extends CRM_Import_Form_Preview {
       'dedupe' => $this->get('dedupe'),
       'newGroupName' => $this->controller->exportValue($this->_name, 'newGroupName'),
       'newGroupDesc' => $this->controller->exportValue($this->_name, 'newGroupDesc'),
+      'newGroupType' => $this->controller->exportValue($this->_name, 'newGroupType'),
       'groups' => $this->controller->exportValue($this->_name, 'groups'),
       'allGroups' => $this->get('groups'),
       'newTagName' => $this->controller->exportValue($this->_name, 'newTagName'),
@@ -282,15 +299,13 @@ class CRM_Contact_Import_Form_Preview extends CRM_Import_Form_Preview {
       CRM_ACL_BAO_Cache::updateEntry($userID);
     }
 
+    CRM_Utils_Address_USPS::disable($this->_disableUSPS);
+
     // run the import
     $importJob->runImport($this);
 
-    // update cache after we done with runImport
-    if (!CRM_Core_Permission::check('view all contacts')) {
-      CRM_ACL_BAO_Cache::updateEntry($userID);
-    }
-
-    // clear all caches
+    // Clear all caches, forcing any searches to recheck the ACLs or group membership as the import
+    // may have changed it.
     CRM_Contact_BAO_Contact_Utils::clearContactCaches();
 
     // add all the necessary variables to the form
@@ -343,6 +358,7 @@ class CRM_Contact_Import_Form_Preview extends CRM_Import_Form_Preview {
     $onDuplicate = $this->get('onDuplicate');
     $newGroupName = $this->controller->exportValue($this->_name, 'newGroupName');
     $newGroupDesc = $this->controller->exportValue($this->_name, 'newGroupDesc');
+    $newGroupType = $this->controller->exportValue($this->_name, 'newGroupType');
     $groups = $this->controller->exportValue($this->_name, 'groups');
     $allGroups = $this->get('groups');
     $newTagName = $this->controller->exportValue($this->_name, 'newTagName');
@@ -474,6 +490,7 @@ class CRM_Contact_Import_Form_Preview extends CRM_Import_Form_Preview {
         'name' => $newGroupName,
         'title' => $newGroupName,
         'description' => $newGroupDesc,
+        'group_type' => $newGroupType,
         'is_active' => TRUE,
       );
       $group = CRM_Contact_BAO_Group::create($gParams);
