@@ -51,16 +51,13 @@ class CRM_Contact_Page_Dashlet extends CRM_Core_Page {
     $currentDashlets = CRM_Core_BAO_Dashboard::getContactDashlets();
     $contactDashlets = $availableDashlets = array();
 
-    foreach ($currentDashlets as $columnNo => $values) {
-      foreach ($values as $val => $isMinimized) {
-        list($weight, $dashletID) = explode('-', $val);
-        $key = "{$dashletID}-{$isMinimized}";
-        $contactDashlets[$columnNo][$key] = array(
-          'label' => $allDashlets[$dashletID]['label'],
-          'is_reserved' => $allDashlets[$dashletID]['is_reserved'],
-        );
-        unset($allDashlets[$dashletID]);
-      }
+    foreach ($currentDashlets as $item) {
+      $key = "{$item['dashboard_id']}-0";
+      $contactDashlets[$item['column_no']][$key] = array(
+        'label' => $item['label'],
+        'is_reserved' => $allDashlets[$item['dashboard_id']]['is_reserved'],
+      );
+      unset($allDashlets[$item['dashboard_id']]);
     }
 
     foreach ($allDashlets as $dashletID => $values) {
