@@ -55,15 +55,15 @@ class CRM_Contact_Page_DedupeMerge extends CRM_Core_Page {
    * Build a queue of tasks by dividing dupe pairs in batches.
    */
   public static function getRunner() {
-    $rgid = CRM_Utils_Request::retrieve('rgid', 'Positive', $this, FALSE, 0);
-    $gid  = CRM_Utils_Request::retrieve('gid', 'Positive', $this, FALSE, 0);
-    $action = CRM_Utils_Request::retrieve('action', 'String', CRM_Core_DAO::$_nullObject);
+    $rgid = CRM_Utils_Request::retrieve('rgid', 'Positive');
+    $gid  = CRM_Utils_Request::retrieve('gid', 'Positive');
+    $limit  = CRM_Utils_Request::retrieve('limit', 'Positive');
+    $action = CRM_Utils_Request::retrieve('action', 'String');
     $mode   = CRM_Utils_Request::retrieve('mode', 'String', CRM_Core_DAO::$_nullObject, FALSE, 'safe');
 
     $cacheKeyString = CRM_Dedupe_Merger::getMergeCacheKeyString($rgid, $gid);
 
-    $urlQry = "reset=1&action=update&rgid={$rgid}";
-    $urlQry = $gid ? ($urlQry . "&gid={$gid}") : $urlQry;
+    $urlQry = "reset=1&action=update&rgid={$rgid}&gid={$gid}&limit={$limit}";
 
     if ($mode == 'aggressive' && !CRM_Core_Permission::check('force merge duplicate contacts')) {
       CRM_Core_Session::setStatus(ts('You do not have permission to force merge duplicate contact records'), ts('Permission Denied'), 'error');
@@ -98,7 +98,7 @@ class CRM_Contact_Page_DedupeMerge extends CRM_Core_Page {
     for ($i = 1; $i <= ceil($total / self::BATCHLIMIT); $i++) {
       $task  = new CRM_Queue_Task(
         array('CRM_Contact_Page_DedupeMerge', 'callBatchMerge'),
-        array($rgid, $gid, $mode, TRUE, self::BATCHLIMIT, $isSelected),
+        array($rgid, $gid, $mode, FALSE, self::BATCHLIMIT, $isSelected),
         "Processed " . $i * self::BATCHLIMIT . " pair of duplicates out of " . $total
       );
 
@@ -125,15 +125,18 @@ class CRM_Contact_Page_DedupeMerge extends CRM_Core_Page {
    * @param int $rgid
    * @param int $gid
    * @param string $mode
+   *   'safe' mode or 'force' mode.
    * @param bool $autoFlip
+   *   Override the values in the prevnext table & use the lowest value?
+   *   As the form offers the user to flip the values themselves this should
+   *   only be TRUE if you wish to ignore the user.
    * @param int $batchLimit
    * @param int $isSelected
    *
    * @return int
    */
-  public static function callBatchMerge(CRM_Queue_TaskContext $ctx, $rgid, $gid = NULL, $mode = 'safe', $autoFlip = TRUE, $batchLimit = 1, $isSelected = 2) {
-    $result = CRM_Dedupe_Merger::batchMerge($rgid, $gid, $mode, $autoFlip, $batchLimit, $isSelected);
-
+  public static function callBatchMerge(CRM_Queue_TaskContext $ctx, $rgid, $gid, $mode = 'safe', $autoFlip, $batchLimit, $isSelected) {
+    CRM_Dedupe_Merger::batchMerge($rgid, $gid, $mode, $autoFlip, $batchLimit, $isSelected);
     return CRM_Queue_Task::TASK_SUCCESS;
   }
 
