@@ -166,10 +166,7 @@ class CRM_Contact_Page_View_Note extends CRM_Core_Page {
     );
     $session->pushUserContext($url);
 
-    if (CRM_Utils_Request::retrieve('confirmed', 'Boolean',
-      CRM_Core_DAO::$_nullObject
-    )
-    ) {
+    if (CRM_Utils_Request::retrieve('confirmed', 'Boolean')) {
       CRM_Core_BAO_Note::del($this->_id);
       CRM_Utils_System::redirect($url);
     }
