@@ -56,7 +56,7 @@ class CRM_Contact_Page_View_Summary extends CRM_Contact_Page_View {
         trim($entitySubType, CRM_Core_DAO::VALUE_SEPARATOR)
       );
     }
-    $groupTree = &CRM_Core_BAO_CustomGroup::getTree($entityType,
+    $groupTree = CRM_Core_BAO_CustomGroup::getTree($entityType,
       $this,
       $this->_contactId,
       NULL,
@@ -392,6 +392,13 @@ class CRM_Contact_Page_View_Summary extends CRM_Contact_Page_View {
     CRM_Utils_Hook::tabs($allTabs, $this->_contactId);
     CRM_Utils_Hook::tabset('civicrm/contact/view', $allTabs, $context);
 
+    $allTabs[] = array(
+      'id' => 'summary',
+      'url' => '#contact-summary',
+      'title' => ts('Summary'),
+      'weight' => 0,
+    );
+
     // now sort the tabs based on weight
     usort($allTabs, array('CRM_Utils_Sort', 'cmpFunc'));
 
