@@ -76,8 +76,6 @@ AND    {$this->_componentClause}";
       CRM_Core_Error::statusBounce("Please select only online contributions with Completed status.");
     }
 
-    // we have all the contribution ids, so now we get the contact ids
-    parent::setContactIDs();
     $this->assign('single', $this->_single);
 
     $qfKey = CRM_Utils_Request::retrieve('qfKey', 'String', $this);
@@ -93,7 +91,9 @@ AND    {$this->_componentClause}";
         'title' => ts('Search Results'),
       ),
     );
-
+    CRM_Contact_Form_Task_EmailCommon ::preProcessFromAddress($this, FALSE);
+    // we have all the contribution ids, so now we get the contact ids
+    parent::setContactIDs();
     CRM_Utils_System::appendBreadCrumb($breadCrumb);
     CRM_Utils_System::setTitle(ts('Print Contribution Receipts'));
   }
@@ -104,7 +104,9 @@ AND    {$this->_componentClause}";
   public function buildQuickForm() {
 
     $this->addElement('radio', 'output', NULL, ts('Email Receipts'), 'email_receipt',
-      array('onClick' => "document.getElementById('selectPdfFormat').style.display = 'none';")
+      array(
+        'onClick' => "document.getElementById('selectPdfFormat').style.display = 'none';
+        document.getElementById('selectEmailFrom').style.display = 'block';")
     );
     $this->addElement('radio', 'output', NULL, ts('PDF Receipts'), 'pdf_receipt',
       array('onClick' => "document.getElementById('selectPdfFormat').style.display = 'block';")
@@ -117,6 +119,8 @@ AND    {$this->_componentClause}";
     $this->add('checkbox', 'receipt_update', ts('Update receipt dates for these contributions'), FALSE);
     $this->add('checkbox', 'override_privacy', ts('Override privacy setting? (Do not email / Do not mail)'), FALSE);
 
+    $this->add('select', 'fromEmailAddress', ts('From Email'), $this->_fromEmails, FALSE, array('class' => 'crm-select2 huge'));
+
     $this->addButtons(array(
         array(
           'type' => 'next',
@@ -182,11 +186,26 @@ AND    {$this->_componentClause}";
       $input['trxn_date'] = isset($contribution->trxn_date) ? $contribution->trxn_date : NULL;
       $input['receipt_update'] = $params['receipt_update'];
       $input['contribution_status_id'] = $contribution->contribution_status_id;
+      $input['paymentProcessor'] = empty($contribution->trxn_id) ? NULL :
+        CRM_Core_DAO::singleValueQuery("SELECT payment_processor_id
+          FROM civicrm_financial_trxn
+          WHERE trxn_id = %1
+          LIMIT 1", array(
+            1 => array($contribution->trxn_id, 'String')));
 
       // CRM_Contribute_BAO_Contribution::composeMessageArray expects mysql formatted date
       $objects['contribution']->receive_date = CRM_Utils_Date::isoToMysql($objects['contribution']->receive_date);
 
       $values = array();
+      if (isset($params['fromEmailAddress']) && !$elements['createPdf']) {
+        // CRM-19129 Allow useres the choice of From Email to send the receipt from.
+        $fromEmail = $params['fromEmailAddress'];
+        $from = CRM_Utils_Array::value($fromEmail, $this->_emails);
+        $fromDetails = explode(' <', $from);
+        $input['receipt_from_email'] = substr(trim($fromDetails[1]), 0, -1);
+        $input['receipt_from_name'] = str_replace('"', '', $fromDetails[0]);
+      }
+
       $mail = CRM_Contribute_BAO_Contribution::sendMail($input, $ids, $objects['contribution']->id, $values, FALSE,
         $elements['createPdf']);
 
