@@ -100,9 +100,7 @@ class CRM_Contribute_Form_UpdateSubscription extends CRM_Core_Form {
       $this->_coid = CRM_Core_DAO::getFieldValue('CRM_Contribute_DAO_Contribution', $this->contributionRecurID, 'id', 'contribution_recur_id');
     }
 
-    if ((!$this->contributionRecurID) ||
-      ($this->_subscriptionDetails == CRM_Core_DAO::$_nullObject)
-    ) {
+    if (!$this->contributionRecurID || !$this->_subscriptionDetails) {
       CRM_Core_Error::fatal('Required information missing.');
     }
 
