@@ -79,6 +79,7 @@ class CRM_Core_ClassLoader {
       'CiviSeleniumTestCase',
       'CiviTestSuite',
       'CiviUnitTestCase',
+      'CiviEndToEndTestCase',
       'Contact',
       'ContributionPage',
       'Custom',
@@ -181,7 +182,7 @@ class CRM_Core_ClassLoader {
     if (
       // Only load classes that clearly belong to CiviCRM.
       // Note: api/v3 does not use classes, but api_v3's test-suite does
-      (0 === strncmp($class, 'CRM_', 4) || 0 === strncmp($class, 'api_v3_', 7) || 0 === strncmp($class, 'WebTest_', 8)) &&
+      (0 === strncmp($class, 'CRM_', 4) || 0 === strncmp($class, 'api_v3_', 7) || 0 === strncmp($class, 'WebTest_', 8) || 0 === strncmp($class, 'E2E_', 4)) &&
       // Do not load PHP 5.3 namespaced classes.
       // (in a future version, maybe)
       FALSE === strpos($class, '\\')
