@@ -32,7 +32,7 @@
  * $Id$
  *
  */
-class CRM_Core_I18n_SchemaStructure_3_4_0 {
+class CRM_Core_I18n_SchemaStructure_4_3_1 {
   /**
    * @return array
    */
@@ -40,30 +40,33 @@ class CRM_Core_I18n_SchemaStructure_3_4_0 {
     static $result = NULL;
     if (!$result) {
       $result = array(
+        'civicrm_location_type' => array(
+          'display_name' => "varchar(64)",
+        ),
         'civicrm_option_group' => array(
-          'label' => "varchar(255)",
+          'title' => "varchar(255)",
           'description' => "varchar(255)",
         ),
         'civicrm_contact_type' => array(
           'label' => "varchar(64)",
           'description' => "text",
         ),
+        'civicrm_batch' => array(
+          'title' => "varchar(64)",
+          'description' => "text",
+        ),
         'civicrm_premiums' => array(
           'premiums_intro_title' => "varchar(255)",
           'premiums_intro_text' => "text",
-        ),
-        'civicrm_product' => array(
-          'name' => "varchar(255)",
-          'description' => "text",
-          'options' => "text",
-        ),
-        'civicrm_membership_type' => array(
-          'name' => "varchar(128)",
-          'description' => "varchar(255)",
+          'premiums_nothankyou_label' => "varchar(255)",
         ),
         'civicrm_membership_status' => array(
           'label' => "varchar(128)",
         ),
+        'civicrm_survey' => array(
+          'thankyou_title' => "varchar(255)",
+          'thankyou_text' => "text",
+        ),
         'civicrm_participant_status_type' => array(
           'label' => "varchar(255)",
         ),
@@ -74,15 +77,6 @@ class CRM_Core_I18n_SchemaStructure_3_4_0 {
           'thankyou_title' => "varchar(255)",
           'thankyou_text' => "text",
         ),
-        'civicrm_price_set' => array(
-          'title' => "varchar(255)",
-          'help_pre' => "text",
-          'help_post' => "text",
-        ),
-        'civicrm_batch' => array(
-          'label' => "varchar(64)",
-          'description' => "text",
-        ),
         'civicrm_custom_group' => array(
           'title' => "varchar(64)",
           'help_pre' => "text",
@@ -93,18 +87,20 @@ class CRM_Core_I18n_SchemaStructure_3_4_0 {
           'help_pre' => "text",
           'help_post' => "text",
         ),
-        'civicrm_dashboard' => array(
-          'label' => "varchar(255)",
-        ),
         'civicrm_option_value' => array(
           'label' => "varchar(255)",
           'description' => "text",
         ),
+        'civicrm_group' => array(
+          'title' => "varchar(64)",
+        ),
         'civicrm_contribution_page' => array(
           'title' => "varchar(255)",
           'intro_text' => "text",
           'pay_later_text' => "text",
           'pay_later_receipt' => "text",
+          'initial_amount_label' => "varchar(255)",
+          'initial_amount_help_text' => "text",
           'thankyou_title' => "varchar(255)",
           'thankyou_text' => "text",
           'thankyou_footer' => "text",
@@ -115,20 +111,28 @@ class CRM_Core_I18n_SchemaStructure_3_4_0 {
           'honor_block_title' => "varchar(255)",
           'honor_block_text' => "text",
         ),
+        'civicrm_product' => array(
+          'name' => "varchar(255)",
+          'description' => "text",
+          'options' => "text",
+        ),
+        'civicrm_membership_type' => array(
+          'name' => "varchar(128)",
+          'description' => "varchar(255)",
+        ),
         'civicrm_membership_block' => array(
           'new_title' => "varchar(255)",
           'new_text' => "text",
           'renewal_title' => "varchar(255)",
           'renewal_text' => "text",
         ),
-        'civicrm_price_field' => array(
-          'label' => "varchar(255)",
+        'civicrm_price_set' => array(
+          'title' => "varchar(255)",
           'help_pre' => "text",
           'help_post' => "text",
         ),
-        'civicrm_price_field_value' => array(
+        'civicrm_dashboard' => array(
           'label' => "varchar(255)",
-          'description' => "text",
         ),
         'civicrm_uf_group' => array(
           'title' => "varchar(64)",
@@ -140,6 +144,18 @@ class CRM_Core_I18n_SchemaStructure_3_4_0 {
           'help_pre' => "text",
           'label' => "varchar(255)",
         ),
+        'civicrm_price_field' => array(
+          'label' => "varchar(255)",
+          'help_pre' => "text",
+          'help_post' => "text",
+        ),
+        'civicrm_price_field_value' => array(
+          'label' => "varchar(255)",
+          'description' => "text",
+        ),
+        'civicrm_pcp_block' => array(
+          'link_text' => "varchar(255)",
+        ),
         'civicrm_event' => array(
           'title' => "varchar(255)",
           'summary' => "text",
@@ -159,6 +175,8 @@ class CRM_Core_I18n_SchemaStructure_3_4_0 {
           'thankyou_footer_text' => "text",
           'pay_later_text' => "text",
           'pay_later_receipt' => "text",
+          'initial_amount_label' => "varchar(255)",
+          'initial_amount_help_text' => "text",
           'waitlist_text' => "text",
           'approval_req_text' => "text",
           'template_title' => "varchar(255)",
@@ -175,15 +193,6 @@ class CRM_Core_I18n_SchemaStructure_3_4_0 {
     static $result = NULL;
     if (!$result) {
       $result = array(
-        'civicrm_price_set' => array(
-          'UI_title' => array(
-            'name' => 'UI_title',
-            'field' => array(
-              'title',
-            ),
-            'unique' => 1,
-          ),
-        ),
         'civicrm_custom_group' => array(
           'UI_title_extends' => array(
             'name' => 'UI_title_extends',
@@ -204,6 +213,15 @@ class CRM_Core_I18n_SchemaStructure_3_4_0 {
             'unique' => 1,
           ),
         ),
+        'civicrm_group' => array(
+          'UI_title' => array(
+            'name' => 'UI_title',
+            'field' => array(
+              'title',
+            ),
+            'unique' => 1,
+          ),
+        ),
       );
     }
     return $result;
