@@ -35,13 +35,21 @@
 class CRM_Core_Page_File extends CRM_Core_Page {
 
   public function run() {
-    $eid = CRM_Utils_Request::retrieve('eid', 'Positive', $this, TRUE);
-    $fid = CRM_Utils_Request::retrieve('fid', 'Positive', $this, FALSE);
-    $id = CRM_Utils_Request::retrieve('id', 'Positive', $this, TRUE);
-    $quest = CRM_Utils_Request::retrieve('quest', 'String', $this);
+    $fileName = CRM_Utils_Request::retrieve('filename', 'String', $this);
+    $path = CRM_Core_Config::singleton()->customFileUploadDir . $fileName;
+    $mimeType = CRM_Utils_Request::retrieve('mime-type', 'String', $this);
     $action = CRM_Utils_Request::retrieve('action', 'String', $this);
 
-    list($path, $mimeType) = CRM_Core_BAO_File::path($id, $eid, NULL, $quest);
+    // if we are not providing essential parameter needed for file preview then
+    if (empty($fileName) && empty($mimeType)) {
+      $eid = CRM_Utils_Request::retrieve('eid', 'Positive', $this, TRUE);
+      $fid = CRM_Utils_Request::retrieve('fid', 'Positive', $this, FALSE);
+      $id = CRM_Utils_Request::retrieve('id', 'Positive', $this, TRUE);
+      $quest = CRM_Utils_Request::retrieve('quest', 'String', $this);
+
+      list($path, $mimeType) = CRM_Core_BAO_File::path($id, $eid, NULL, $quest);
+    }
+
     if (!$path) {
       CRM_Core_Error::statusBounce('Could not retrieve the file');
     }
@@ -52,7 +60,7 @@ class CRM_Core_Page_File extends CRM_Core_Page {
     }
 
     if ($action & CRM_Core_Action::DELETE) {
-      if (CRM_Utils_Request::retrieve('confirmed', 'Boolean', CRM_Core_DAO::$_nullObject)) {
+      if (CRM_Utils_Request::retrieve('confirmed', 'Boolean')) {
         CRM_Core_BAO_File::deleteFileReferences($id, $eid, $fid);
         CRM_Core_Session::setStatus(ts('The attached file has been deleted.'), ts('Complete'), 'success');
 
