@@ -278,7 +278,7 @@ class CRM_Event_Form_ParticipantFeeSelection extends CRM_Core_Form {
    * @return mixed
    */
   public function emailReceipt(&$params) {
-    $updatedLineItem = CRM_Price_BAO_LineItem::getLineItems($this->_participantId, 'participant', NULL, FALSE);
+    $updatedLineItem = CRM_Price_BAO_LineItem::getLineItems($this->_participantId, 'participant', FALSE, FALSE);
     $lineItem = array();
     if ($updatedLineItem) {
       $lineItem[] = $updatedLineItem;
