@@ -36,7 +36,7 @@
  * Create a subclass for a specific format.
  * @see http://wiki.civicrm.org/confluence/display/CRM/CiviAccounts+Specifications+-++Batches#CiviAccountsSpecifications-Batches-%C2%A0Overviewofimplementation
  */
-class CRM_Financial_BAO_ExportFormat {
+abstract class CRM_Financial_BAO_ExportFormat {
 
   /**
    * data which the individual export formats will output in the desired format.
@@ -71,23 +71,22 @@ class CRM_Financial_BAO_ExportFormat {
   }
 
   /**
-   * @param null $fileName
+   * Exports sbatches in $this->_batchIds, and saves to file.
+   *
+   * @param string $fileName - use this file name (if applicable)
    */
   public function output($fileName = NULL) {
-    switch ($this->getFileExtension()) {
-      case 'csv':
-        self::createActivityExport($this->_batchIds, $fileName);
-        break;
-
-      case 'iif':
-        $tplFile = $this->getHookedTemplateFileName();
-        $out = self::getTemplate()->fetch($tplFile);
-        $fileName = $this->putFile($out);
-        self::createActivityExport($this->_batchIds, $fileName);
-        break;
-    }
+    // Default behaviour, override if needed:
+    self::createActivityExport($this->_batchIds, $fileName);
   }
 
+  /**
+   * Abstract function that generates exports, and downloads them as zip file.
+   *
+   * @param $exportDaos array with DAO's for queries to be exported.
+   */
+  public abstract function makeExport($exportDaos);
+
   /**
    * @return string
    */
@@ -96,11 +95,14 @@ class CRM_Financial_BAO_ExportFormat {
   }
 
   /**
+   * Returns some kind of identification for your export format.
+   *
+   * This does not really has to be a file extension, you can name your
+   * file as you wish as you override output.
+   *
    * @return string
    */
-  public function getFileExtension() {
-    return 'txt';
-  }
+  public abstract function getFileExtension();
 
   /**
    * @return object
