@@ -104,6 +104,21 @@ class CRM_Financial_Form_FinancialAccount extends CRM_Contribute_Form {
       $element->freeze();
     }
 
+    //CRM-16189
+    if (CRM_Contribute_BAO_Contribution::checkContributeSettings('financial_account_bal_enable')) {
+      $this->add('text', 'opening_balance', ts('Opening Balance'), $attributes['opening_balance']);
+      $this->add('text', 'current_period_opening_balance', ts('Current Period Opening Balance'), $attributes['current_period_opening_balance']);
+      $financialAccountType = CRM_Core_PseudoConstant::get(
+        'CRM_Financial_DAO_FinancialAccount',
+        'financial_account_type_id',
+        array('labelColumn' => 'name')
+      );
+      $limitedAccount = array(
+        array_search('Asset', $financialAccountType),
+        array_search('Liability', $financialAccountType),
+      );
+      $this->assign('limitedAccount', json_encode($limitedAccount));
+    }
     $financialAccountType = CRM_Core_PseudoConstant::get('CRM_Financial_DAO_FinancialAccount', 'financial_account_type_id');
     if (!empty($financialAccountType)) {
       $element = $this->add('select', 'financial_account_type_id', ts('Financial Account Type'),
@@ -113,6 +128,9 @@ class CRM_Financial_Form_FinancialAccount extends CRM_Contribute_Form {
         $elementAccounting->freeze();
         $elementActive->freeze();
       }
+      elseif ($this->_id && CRM_Financial_BAO_FinancialAccount::validateFinancialAccount($this->_id)) {
+        $element->freeze();
+      }
     }
 
     if ($this->_action == CRM_Core_Action::UPDATE &&
@@ -174,6 +192,7 @@ class CRM_Financial_Form_FinancialAccount extends CRM_Contribute_Form {
     $defaults = parent::setDefaultValues();
     if ($this->_action & CRM_Core_Action::ADD) {
       $defaults['contact_id'] = CRM_Core_DAO::getFieldValue('CRM_Core_DAO_Domain', CRM_Core_Config::domainID(), 'contact_id');
+      $defaults['opening_balance'] = $defaults['current_period_opening_balance'] = '0.00';
     }
     return $defaults;
   }
@@ -183,20 +202,23 @@ class CRM_Financial_Form_FinancialAccount extends CRM_Contribute_Form {
    */
   public function postProcess() {
     if ($this->_action & CRM_Core_Action::DELETE) {
-      CRM_Financial_BAO_FinancialAccount::del($this->_id);
-      CRM_Core_Session::setStatus(ts('Selected Financial Account has been deleted.'));
+      if (CRM_Financial_BAO_FinancialAccount::del($this->_id)) {
+        CRM_Core_Session::setStatus(ts('Selected Financial Account has been deleted.'));
+      }
+      else {
+        CRM_Utils_System::redirect(CRM_Utils_System::url('civicrm/admin/financial/financialAccount', "reset=1&action=browse"));
+      }
     }
     else {
-      $ids = array();
       // store the submitted values in an array
       $params = $this->exportValues();
 
       if ($this->_action & CRM_Core_Action::UPDATE) {
-        $ids['contributionType'] = $this->_id;
+        $params['id'] = $this->_id;
       }
 
-      $contributionType = CRM_Financial_BAO_FinancialAccount::add($params, $ids);
-      CRM_Core_Session::setStatus(ts('The Financial Account \'%1\' has been saved.', array(1 => $contributionType->name)));
+      $financialAccount = CRM_Financial_BAO_FinancialAccount::add($params);
+      CRM_Core_Session::setStatus(ts('The Financial Account \'%1\' has been saved.', array(1 => $financialAccount->name)), ts('Saved'), 'success');
     }
   }
 
