@@ -237,7 +237,7 @@ class CRM_Group_Form_Edit extends CRM_Core_Form {
     );
 
     $groupTypes = CRM_Core_OptionGroup::values('group_type', TRUE);
-    $config = CRM_Core_Config::singleton();
+
     if (isset($this->_id) && !empty($this->_groupValues['saved_search_id'])) {
       unset($groupTypes['Access Control']);
     }
@@ -254,12 +254,7 @@ class CRM_Group_Form_Edit extends CRM_Core_Form {
 
     //CRM-14190
     $parentGroups = self::buildParentGroups($this);
-
-    if (CRM_Core_Permission::check('administer Multiple Organizations') && CRM_Core_Permission::isMultisiteEnabled()) {
-      //group organization Element
-      $props = array('api' => array('params' => array('contact_type' => 'Organization')));
-      $this->addEntityRef('organization_id', ts('Organization'), $props);
-    }
+    self::buildGroupOrganizations($this);
 
     // is_reserved property CRM-9936
     $this->addElement('checkbox', 'is_reserved', ts('Reserved Group?'));
@@ -384,9 +379,18 @@ WHERE  title = %1
       }
 
       $params['is_reserved'] = CRM_Utils_Array::value('is_reserved', $params, FALSE);
-      $params['group_type'] = CRM_Utils_Array::value('group_type', $params, array());
 
-      $customFields = CRM_Core_BAO_CustomField::getFields('Group');
+      $groupTypeIds = array();
+      $groupType = CRM_Utils_Array::value('group_type', $params);
+      if (is_array($groupType)) {
+        foreach ($groupType as $type => $selected) {
+          if ($selected) {
+            $groupTypeIds[] = $type;
+          }
+        }
+      }
+      $params['group_type'] = $groupTypeIds;
+
       $params['custom'] = CRM_Core_BAO_CustomField::postProcess($params,
         $this->_id,
         'Group'
@@ -475,4 +479,20 @@ WHERE  title = %1
     return $parentGroups;
   }
 
+  /**
+   * Add the group organization checkbox to the form.
+   *
+   * Note this was traditionally a multisite thing - there is no particular reason why it is not available
+   * as a general field - it's historical use-case driven.
+   *
+   * @param CRM_Core_Form $form
+   */
+  public static function buildGroupOrganizations(&$form) {
+    if (CRM_Core_Permission::check('administer Multiple Organizations') && CRM_Core_Permission::isMultisiteEnabled()) {
+      //group organization Element
+      $props = array('api' => array('params' => array('contact_type' => 'Organization')));
+      $form->addEntityRef('organization_id', ts('Organization'), $props);
+    }
+  }
+
 }
