@@ -235,7 +235,7 @@ class CRM_Import_DataSource_CSV extends CRM_Import_DataSource {
         function($string) {
           return trim($string, chr(0xC2) . chr(0xA0));
         }, $row);
-      $row = array_map('civicrm_mysql_real_escape_string', $row);
+      $row = array_map(array('CRM_Core_DAO', 'escapeString'), $row);
       $sql .= "('" . implode("', '", $row) . "')";
       $count++;
 
@@ -263,16 +263,3 @@ class CRM_Import_DataSource_CSV extends CRM_Import_DataSource {
   }
 
 }
-
-/**
- * @param $string
- *
- * @return string
- */
-function civicrm_mysql_real_escape_string($string) {
-  static $dao = NULL;
-  if (!$dao) {
-    $dao = new CRM_Core_DAO();
-  }
-  return $dao->escape($string);
-}
