@@ -352,14 +352,14 @@ class CRM_Logging_ReportDetail extends CRM_Report_Form {
    * Get the properties that might be in the URL.
    */
   protected function parsePropertiesFromUrl() {
-    $this->log_conn_id = CRM_Utils_Request::retrieve('log_conn_id', 'String', CRM_Core_DAO::$_nullObject);
-    $this->log_date = CRM_Utils_Request::retrieve('log_date', 'String', CRM_Core_DAO::$_nullObject);
-    $this->cid = CRM_Utils_Request::retrieve('cid', 'Integer', CRM_Core_DAO::$_nullObject);
-    $this->raw = CRM_Utils_Request::retrieve('raw', 'Boolean', CRM_Core_DAO::$_nullObject);
+    $this->log_conn_id = CRM_Utils_Request::retrieve('log_conn_id', 'String');
+    $this->log_date = CRM_Utils_Request::retrieve('log_date', 'String');
+    $this->cid = CRM_Utils_Request::retrieve('cid', 'Integer');
+    $this->raw = CRM_Utils_Request::retrieve('raw', 'Boolean');
 
-    $this->altered_name = CRM_Utils_Request::retrieve('alteredName', 'String', CRM_Core_DAO::$_nullObject);
-    $this->altered_by = CRM_Utils_Request::retrieve('alteredBy', 'String', CRM_Core_DAO::$_nullObject);
-    $this->altered_by_id = CRM_Utils_Request::retrieve('alteredById', 'Integer', CRM_Core_DAO::$_nullObject);
+    $this->altered_name = CRM_Utils_Request::retrieve('alteredName', 'String');
+    $this->altered_by = CRM_Utils_Request::retrieve('alteredBy', 'String');
+    $this->altered_by_id = CRM_Utils_Request::retrieve('alteredById', 'Integer');
   }
 
 }
