@@ -42,9 +42,9 @@ class CRM_Mailing_Page_Common extends CRM_Core_Page {
    * @throws Exception
    */
   public function run() {
-    $job_id = CRM_Utils_Request::retrieve('jid', 'Integer', CRM_Core_DAO::$_nullObject);
-    $queue_id = CRM_Utils_Request::retrieve('qid', 'Integer', CRM_Core_DAO::$_nullObject);
-    $hash = CRM_Utils_Request::retrieve('h', 'String', CRM_Core_DAO::$_nullObject);
+    $job_id = CRM_Utils_Request::retrieve('jid', 'Integer');
+    $queue_id = CRM_Utils_Request::retrieve('qid', 'Integer');
+    $hash = CRM_Utils_Request::retrieve('h', 'String');
 
     if (!$job_id ||
       !$queue_id ||
