@@ -30,7 +30,7 @@
  * @package CRM
  * @copyright CiviCRM LLC (c) 2004-2016
  */
-class CRM_Pledge_BAO_Query {
+class CRM_Pledge_BAO_Query extends CRM_Core_BAO_Query {
   /**
    * Get pledge fields.
    *
@@ -430,15 +430,6 @@ class CRM_Pledge_BAO_Query {
     return $from;
   }
 
-  /**
-   * Getter for the qill object.
-   *
-   * @return string
-   */
-  public function qill() {
-    return (isset($this->_qill)) ? $this->_qill : "";
-  }
-
   /**
    * Ideally this function should include fields that are displayed in the selector.
    *
@@ -534,13 +525,8 @@ class CRM_Pledge_BAO_Query {
     $form->add('text', 'pledge_amount_high', ts('To'), array('size' => 8, 'maxlength' => 8));
     $form->addRule('pledge_amount_high', ts('Please enter a valid money value (e.g. %1).', array(1 => CRM_Utils_Money::format('99.99', ' '))), 'money');
 
-    $statusValues = CRM_Contribute_PseudoConstant::contributionStatus();
-    // Remove status values that are only used for recurring contributions for now (Failed and In Progress).
-    unset($statusValues['4']);
-    // unset in progress for payment
-    unset($statusValues['5']);
     $form->add('select', 'pledge_status_id',
-      ts('Pledge Status'), $statusValues,
+      ts('Pledge Status'), CRM_Pledge_BAO_Pledge::buildOptions('status_id'),
       FALSE, array('class' => 'crm-select2', 'multiple' => 'multiple')
     );
 
@@ -553,7 +539,7 @@ class CRM_Pledge_BAO_Query {
     $form->addRule('pledge_installments_high', ts('Please enter number.'), 'integer');
 
     $form->add('select', 'pledge_payment_status_id',
-      ts('Pledge Payment Status'), $statusValues,
+      ts('Pledge Payment Status'), CRM_Pledge_BAO_PledgePayment::buildOptions('status_id'),
       FALSE, array('class' => 'crm-select2', 'multiple' => 'multiple')
     );
 
@@ -582,19 +568,7 @@ class CRM_Pledge_BAO_Query {
       array('' => ts('- any -')) + $freqUnitsDisplay
     );
 
-    // add all the custom  searchable fields
-    $pledge = array('Pledge');
-    $groupDetails = CRM_Core_BAO_CustomGroup::getGroupDetail(NULL, TRUE, $pledge);
-    if ($groupDetails) {
-      $form->assign('pledgeGroupTree', $groupDetails);
-      foreach ($groupDetails as $group) {
-        foreach ($group['fields'] as $field) {
-          $fieldId = $field['id'];
-          $elementName = 'custom_' . $fieldId;
-          CRM_Core_BAO_CustomField::addQuickFormElement($form, $elementName, $fieldId, FALSE, TRUE);
-        }
-      }
-    }
+    self::addCustomFormFields($form, array('Pledge'));
 
     CRM_Campaign_BAO_Campaign::addCampaignInComponentSearch($form, 'pledge_campaign_id');
 
@@ -602,13 +576,6 @@ class CRM_Pledge_BAO_Query {
     $form->setDefaults(array('pledge_test' => 0));
   }
 
-  /**
-   * @param $row
-   * @param int $id
-   */
-  public static function searchAction(&$row, $id) {
-  }
-
   /**
    * @param $tables
    */
