@@ -37,8 +37,9 @@
 class CRM_Pledge_Page_DashBoard extends CRM_Core_Page {
 
   /**
-   * Heart of the viewing process: The runner gets all the meta data for
-   * the contact and calls the appropriate type of page to view.
+   * Heart of the viewing process.
+   *
+   * The runner gets all the meta data for the contact and calls the appropriate type of page to view.
    */
   public function preProcess() {
     CRM_Utils_System::setTitle(ts('CiviPledge'));
@@ -56,8 +57,7 @@ class CRM_Pledge_Page_DashBoard extends CRM_Core_Page {
     $startDateEnd = NULL;
 
     // current year - prefix = 'year'
-    $config = CRM_Core_Config::singleton();
-    $yearDate = $config->fiscalYearStart;
+    $yearDate = \Civi::settings()->get('fiscalYearStart');
     $year = array('Y' => date('Y'));
     $this->assign('curYear', $year['Y']);
     $yearDate = array_merge($year, $yearDate);
@@ -89,7 +89,8 @@ class CRM_Pledge_Page_DashBoard extends CRM_Core_Page {
   }
 
   /**
-   * the main function that is called when the page loads,
+   * The main function that is called when the page loads.
+   *
    * it decides which action has to be taken for the page.
    *
    * @return null
