@@ -290,9 +290,7 @@ class CRM_Pledge_Selector_Search extends CRM_Core_Selector_Base {
     $rows = array();
 
     // get all pledge status
-    $pledgeStatuses = CRM_Core_OptionGroup::values('contribution_status',
-      FALSE, FALSE, FALSE, NULL, 'name', FALSE
-    );
+    $pledgeStatuses = CRM_Pledge_BAO_Pledge::buildOptions('status_id');
 
     // get all campaigns.
     $allCampaigns = CRM_Campaign_BAO_Campaign::getCampaigns(NULL, NULL, FALSE, FALSE, FALSE, TRUE);
