@@ -210,18 +210,20 @@ class CRM_Report_BAO_ReportInstance extends CRM_Report_DAO_ReportInstance {
     // add to dashlet
     if (!empty($dashletParams)) {
       $section = 2;
-      $chart = '';
+      $chart = $limitResult = '';
       if (!empty($params['charts'])) {
         $section = 1;
         $chart = "&charts=" . $params['charts'];
       }
-      $limitResult = NULL;
-      if (!empty($params['row_count'])) {
+      if (!empty($params['row_count']) && CRM_Utils_Rule::positiveInteger($params['row_count'])) {
         $limitResult = '&rowCount=' . $params['row_count'];
       }
+      if (!empty($params['cache_minutes']) && CRM_Utils_Rule::positiveInteger($params['cache_minutes'])) {
+        $dashletParams['cache_minutes'] = $params['cache_minutes'];
+      }
       $dashletParams['name'] = "report/{$instance->id}";
-      $dashletParams['url'] = "civicrm/report/instance/{$instance->id}?reset=1&section={$section}&snippet=5{$chart}&context=dashlet" . $limitResult;
-      $dashletParams['fullscreen_url'] = "civicrm/report/instance/{$instance->id}?reset=1&section={$section}&snippet=5{$chart}&context=dashletFullscreen" . $limitResult;
+      $dashletParams['url'] = "civicrm/report/instance/{$instance->id}?reset=1&section={$section}{$chart}&context=dashlet" . $limitResult;
+      $dashletParams['fullscreen_url'] = "civicrm/report/instance/{$instance->id}?reset=1&section={$section}{$chart}&context=dashletFullscreen" . $limitResult;
       $dashletParams['instanceURL'] = "civicrm/report/instance/{$instance->id}";
       CRM_Core_BAO_Dashboard::addDashlet($dashletParams);
     }
@@ -239,9 +241,17 @@ class CRM_Report_BAO_ReportInstance extends CRM_Report_DAO_ReportInstance {
    *   $results no of deleted Instance on success, false otherwise
    */
   public static function del($id = NULL) {
+    $navId = CRM_Core_DAO::getFieldValue('CRM_Report_DAO_ReportInstance', $id, 'navigation_id', 'id');
     $dao = new CRM_Report_DAO_ReportInstance();
     $dao->id = $id;
-    return $dao->delete();
+    $result = $dao->delete();
+
+    // Delete navigation if exists.
+    if ($navId) {
+      CRM_Core_BAO_Navigation::processDelete($navId);
+      CRM_Core_BAO_Navigation::resetNavigation();
+    }
+    return $result;
   }
 
   /**
@@ -264,4 +274,124 @@ class CRM_Report_BAO_ReportInstance extends CRM_Report_DAO_ReportInstance {
     return NULL;
   }
 
+  /**
+   * Check if report is private.
+   *
+   * @param int $instance_id
+   *
+   * @return bool
+   */
+  public static function reportIsPrivate($instance_id) {
+    $owner_id = CRM_Core_DAO::getFieldValue('CRM_Report_DAO_ReportInstance', $instance_id, 'owner_id', 'id');
+    if ($owner_id) {
+      return TRUE;
+    }
+    return FALSE;
+  }
+
+  /**
+   * Check if the logged in user is the owner.
+   *
+   * @param int $instance_id
+   *
+   * @return TRUE if contact owns the report, FALSE if not
+   */
+  public static function contactIsOwner($instance_id) {
+    $session = CRM_Core_Session::singleton();
+    $contact_id = $session->get('userID');
+    $owner_id = CRM_Core_DAO::getFieldValue('CRM_Report_DAO_ReportInstance', $instance_id, 'owner_id', 'id');
+    if ($contact_id === $owner_id) {
+      return TRUE;
+    }
+    return FALSE;
+  }
+
+  /**
+   * Check if the logged in contact can administer the report.
+   *
+   * @param int $instance_id
+   *
+   * @return bool
+   *   True if contact can edit the private report, FALSE if not.
+   */
+  public static function contactCanAdministerReport($instance_id) {
+    if (self::reportIsPrivate($instance_id)) {
+      if (self::contactIsOwner($instance_id) || CRM_Core_Permission::check('access all private reports')) {
+        return TRUE;
+      }
+    }
+    elseif (CRM_Core_Permission::check('administer Reports')) {
+      return TRUE;
+    }
+    return FALSE;
+  }
+
+  /**
+   * Delete a report instance wrapped in handling for the form layer.
+   *
+   * @param int $instanceId
+   * @param string $bounceTo
+   *   Url to redirect the browser to on fail.
+   * @param string $successRedirect
+   */
+  public static function doFormDelete($instanceId, $bounceTo = 'civicrm/report/list?reset=1', $successRedirect = NULL) {
+    if (!CRM_Core_Permission::check('administer Reports')) {
+      $statusMessage = ts('You do not have permission to Delete Report.');
+      CRM_Core_Error::statusBounce($statusMessage, $bounceTo);
+    }
+
+    CRM_Report_BAO_ReportInstance::del($instanceId);
+
+    CRM_Core_Session::setStatus(ts('Selected report has been deleted.'), ts('Deleted'), 'success');
+    if ($successRedirect) {
+      CRM_Utils_System::redirect(CRM_Utils_System::url($successRedirect));
+    }
+  }
+
+  /**
+   * Get the metadata of actions available for this entity.
+   *
+   * The thinking here is to describe the various actions on the BAO and then functions
+   * can add a mix of actions from different BAO as appropriate. The crm.SearchForm.js code
+   * transforms the 'confirm_mesage' into a message that needs to be confirmed.
+   * confirm_refresh_fields need to be reviewed & potentially updated at the confirm stage.
+   *
+   * Ideas not yet implemented:
+   *  - supports_modal task can be loaded in a popup, theoretically worked, not attempted.
+   *  - class and or icon - per option icons or classes (I added these in addTaskMenu::addTaskMenu
+   *    but I didn't have the right classes). ie adding  'class' => 'crm-i fa-print' to print / class looked
+   *    wrong, but at the php level it worked https://github.com/civicrm/civicrm-core/pull/8529#issuecomment-227639091
+   *  - general script-add.
+   */
+  public static function getActionMetadata() {
+    $actions = array(
+      'report_instance.save' => array('title' => ts('Save')),
+      'report_instance.copy' => array(
+        'title' => ts('Save a Copy'),
+        'data' => array(
+          'is_confirm' => TRUE,
+          'confirm_title' => ts('Save a copy...'),
+          'confirm_refresh_fields' => json_encode(array(
+            'title' => array('selector' => '.crm-report-instanceForm-form-block-title', 'prepend' => ts('(Copy) ')),
+            'description' => array('selector' => '.crm-report-instanceForm-form-block-description', 'prepend' => ''),
+            'parent_id' => array('selector' => '.crm-report-instanceForm-form-block-parent_id', 'prepend' => ''),
+          )),
+        ),
+      ),
+      'report_instance.print' => array('title' => ts('Print Report')),
+      'report_instance.pdf' => array('title' => ts('Print to PDF')),
+      'report_instance.csv' => array('title' => ts('Export as CSV')),
+    );
+    if (CRM_Core_Permission::check('administer Reports')) {
+      $actions['report_instance.delete'] = array(
+        'title' => ts('Delete report'),
+        'data' => array(
+          'is_confirm' => TRUE,
+          'confirm_message' => ts('Are you sure you want delete this report? This action cannot be undone.'),
+        ),
+      );
+    }
+    return $actions;
+  }
+
 }
