@@ -29,13 +29,11 @@
  *
  * @package CRM
  * @copyright CiviCRM LLC (c) 2004-2016
- * $Id$
- *
  */
 class CRM_Report_Form_Case_TimeSpent extends CRM_Report_Form {
+
   /**
-   */
-  /**
+   * Class constructor.
    */
   public function __construct() {
 
@@ -208,6 +206,7 @@ class CRM_Report_Form_Case_TimeSpent extends CRM_Report_Form {
         }
       }
     }
+    $this->_selectClauses = $select;
 
     $this->_select = "SELECT " . implode(', ', $select) . " ";
   }
@@ -284,12 +283,15 @@ class CRM_Report_Form_Case_TimeSpent extends CRM_Report_Form {
   public function groupBy() {
     $this->_groupBy = '';
     if ($this->has_grouping) {
-      $this->_groupBy = "
-GROUP BY {$this->_aliases['civicrm_contact']}.id,
-";
-      $this->_groupBy .= ($this->has_activity_type) ? "{$this->_aliases['civicrm_activity']}.activity_type_id, " : "";
-      $this->_groupBy .= "civicrm_activity_activity_date_time
-";
+      $groupBy = array(
+        "{$this->_aliases['civicrm_contact']}.id",
+        "civicrm_activity_activity_date_time",
+      );
+      if ($this->has_activity_type) {
+        $groupBy[] = "{$this->_aliases['civicrm_activity']}.activity_type_id";
+      }
+
+      $this->_groupBy = CRM_Contact_BAO_Query::getGroupByFromSelectColumns($this->_selectClauses, $groupBy);
     }
   }
 
