@@ -29,8 +29,6 @@
  *
  * @package CRM
  * @copyright CiviCRM LLC (c) 2004-2016
- * $Id$
- *
  */
 class CRM_Report_Form_Contact_Detail extends CRM_Report_Form {
   const ROW_COUNT_LIMIT = 10;
@@ -45,8 +43,20 @@ class CRM_Report_Form_Contact_Detail extends CRM_Report_Form {
   );
 
   /**
+   * This report has not been optimised for group filtering.
+   *
+   * The functionality for group filtering has been improved but not
+   * all reports have been adjusted to take care of it. This report has not
+   * and will run an inefficient query until fixed.
+   *
+   * CRM-19170
+   *
+   * @var bool
    */
+  protected $groupFilterNotOptimised = TRUE;
+
   /**
+   * Class constructor.
    */
   public function __construct() {
     $this->_autoIncludeIndexedFieldsAsOrderBys = 1;
@@ -89,30 +99,7 @@ class CRM_Report_Form_Contact_Detail extends CRM_Report_Form {
             'title' => ts('Contact Subtype'),
           ),
         ),
-        'filters' => array(
-          'id' => array(
-            'title' => ts('Contact ID'),
-            'no_display' => TRUE,
-          ),
-          'sort_name' => array(
-            'title' => ts('Contact Name'),
-          ),
-          'gender_id' => array(
-            'title' => ts('Gender'),
-            'operatorType' => CRM_Report_Form::OP_MULTISELECT,
-            'options' => CRM_Core_PseudoConstant::get('CRM_Contact_DAO_Contact', 'gender_id'),
-          ),
-          'birth_date' => array(
-            'title' => ts('Birth Date'),
-            'operatorType' => CRM_Report_Form::OP_DATE,
-          ),
-          'contact_type' => array(
-            'title' => ts('Contact Type'),
-          ),
-          'contact_sub_type' => array(
-            'title' => ts('Contact Subtype'),
-          ),
-        ),
+        'filters' => $this->getBasicContactFilters(),
         'grouping' => 'contact-fields',
         'order_bys' => array(
           'sort_name' => array(
@@ -152,18 +139,18 @@ class CRM_Report_Form_Contact_Detail extends CRM_Report_Form {
           ),
         ),
         'order_bys' => array(
-          'state_province_id' => array('title' => 'State/Province'),
-          'city' => array('title' => 'City'),
-          'postal_code' => array('title' => 'Postal Code'),
+          'state_province_id' => array('title' => ts('State/Province')),
+          'city' => array('title' => ts('City')),
+          'postal_code' => array('title' => ts('Postal Code')),
         ),
       ),
       'civicrm_country' => array(
         'dao' => 'CRM_Core_DAO_Country',
         'fields' => array(
-          'name' => array('title' => 'Country', 'default' => TRUE),
+          'name' => array('title' => ts('Country'), 'default' => TRUE),
         ),
         'order_bys' => array(
-          'name' => array('title' => 'Country'),
+          'name' => array('title' => ts('Country')),
         ),
         'grouping' => 'contact-fields',
       ),
@@ -239,7 +226,7 @@ class CRM_Report_Form_Contact_Detail extends CRM_Report_Form {
             'title' => ts('Membership Status'),
             'default' => TRUE,
           ),
-          'source' => array('title' => 'Membership Source'),
+          'source' => array('title' => ts('Membership Source')),
         ),
       ),
       'civicrm_participant' => array(
@@ -296,11 +283,11 @@ class CRM_Report_Form_Contact_Detail extends CRM_Report_Form {
             'default' => TRUE,
           ),
           'start_date' => array(
-            'title' => 'Start Date ',
+            'title' => ts('Start Date'),
             'type' => CRM_Report_Form::OP_DATE,
           ),
           'end_date' => array(
-            'title' => 'End Date ',
+            'title' => ts('End Date'),
             'type' => CRM_Report_Form::OP_DATE,
           ),
         ),
@@ -614,8 +601,6 @@ class CRM_Report_Form_Contact_Detail extends CRM_Report_Form {
     if ($this->_aclWhere) {
       $this->_where .= " AND {$this->_aclWhere} ";
     }
-
-    $this->_where .= " GROUP BY {$this->_aliases['civicrm_contact']}.id ";
   }
 
   /**
@@ -631,7 +616,7 @@ class CRM_Report_Form_Contact_Detail extends CRM_Report_Form {
       ) {
         $sql = "{$this->_selectComponent[$val]} {$this->_formComponent[$val]}
                          WHERE    {$this->_aliases['civicrm_contact']}.id IN ( $selectedContacts )
-                         GROUP BY {$this->_aliases['civicrm_contact']}.id,{$val}.id ";
+                          ";
 
         $dao = CRM_Core_DAO::executeQuery($sql);
         while ($dao->fetch()) {
@@ -656,7 +641,7 @@ class CRM_Report_Form_Contact_Detail extends CRM_Report_Form {
 
     if (!empty($this->_selectComponent['relationship_civireport'])) {
 
-      $relTypes = CRM_Contact_BAO_Relationship::getContactRelationshipType(NULL, 'null', NULL, NULL, TRUE);
+      $relTypes = CRM_Contact_BAO_Relationship::getContactRelationshipType(NULL, NULL, NULL, NULL, TRUE);
 
       $val = 'relationship_civireport';
       $eligibleResult[$val] = $val;
@@ -667,7 +652,7 @@ class CRM_Report_Form_Contact_Detail extends CRM_Report_Form {
                                   {$this->_aliases['civicrm_relationship']}.is_active = 1 AND
                                   contact_a.is_deleted = 0 AND
                                   {$this->_aliases['civicrm_contact']}.is_deleted = 0
-                         GROUP BY {$this->_aliases['civicrm_relationship']}.id";
+                         ";
 
       $dao = CRM_Core_DAO::executeQuery($sql);
       while ($dao->fetch()) {
@@ -724,9 +709,6 @@ class CRM_Report_Form_Contact_Detail extends CRM_Report_Form {
                          civicrm_option_group.name = 'activity_type' AND
                          {$this->_aliases['civicrm_activity']}.is_test = 0 AND
                          ($componentClause)
-
-                 GROUP BY {$this->_aliases['civicrm_activity']}.id
-
                  ORDER BY {$this->_aliases['civicrm_activity']}.activity_date_time desc  ";
 
       $dao = CRM_Core_DAO::executeQuery($sql);
@@ -867,18 +849,12 @@ class CRM_Report_Form_Contact_Detail extends CRM_Report_Form {
           $this->_absoluteUrl
         );
         $rows[$rowNum]['civicrm_contact_sort_name_link'] = $url;
-        $rows[$rowNum]['civicrm_contact_sort_name_hover'] = ts('View Contact Summary for this Contact');
+        $rows[$rowNum]['civicrm_contact_sort_name_hover'] = ts('View Contact Record');
         $entryFound = TRUE;
       }
 
-      //handle gender
-      if (array_key_exists('civicrm_contact_gender_id', $row)) {
-        if ($value = $row['civicrm_contact_gender_id']) {
-          $gender = CRM_Core_PseudoConstant::get('CRM_Contact_DAO_Contact', 'gender_id');
-          $rows[$rowNum]['civicrm_contact_gender_id'] = $gender[$value];
-        }
-        $entryFound = TRUE;
-      }
+      // Handle ID to label conversion for contact fields
+      $entryFound = $this->alterDisplayContactFields($row, $rows, $rowNum, NULL, NULL) ? TRUE : $entryFound;
 
       // display birthday in the configured custom format
       if (array_key_exists('civicrm_contact_birth_date', $row)) {
