@@ -29,8 +29,6 @@
  *
  * @package CRM
  * @copyright CiviCRM LLC (c) 2004-2016
- * $Id$
- *
  */
 class CRM_Report_Form_Event_ParticipantListing extends CRM_Report_Form_Event {
 
@@ -52,8 +50,7 @@ class CRM_Report_Form_Event_ParticipantListing extends CRM_Report_Form_Event {
   public $_drilldownReport = array('event/income' => 'Link to Detail Report');
 
   /**
-   */
-  /**
+   * Class constructor.
    */
   public function __construct() {
     $this->_autoIncludeIndexedFieldsAsOrderBys = 1;
@@ -162,7 +159,7 @@ class CRM_Report_Form_Event_ParticipantListing extends CRM_Report_Form_Event {
       'civicrm_participant' => array(
         'dao' => 'CRM_Event_DAO_Participant',
         'fields' => array(
-          'participant_id' => array('title' => 'Participant ID'),
+          'participant_id' => array('title' => ts('Participant ID')),
           'participant_record' => array(
             'name' => 'id',
             'no_display' => TRUE,
@@ -230,7 +227,7 @@ class CRM_Report_Form_Event_ParticipantListing extends CRM_Report_Form_Event {
             'options' => CRM_Event_PseudoConstant::participantRole(),
           ),
           'participant_register_date' => array(
-            'title' => 'Registration Date',
+            'title' => ts('Registration Date'),
             'operatorType' => CRM_Report_Form::OP_DATE,
           ),
           'fee_currency' => array(
@@ -278,8 +275,15 @@ class CRM_Report_Form_Event_ParticipantListing extends CRM_Report_Form_Event {
       'civicrm_event' => array(
         'dao' => 'CRM_Event_DAO_Event',
         'fields' => array(
-          'event_type_id' => array('title' => ts('Event Type')),
-          'event_start_date' => array('title' => ts('Event Start Date')),
+          'event_type_id' => array(
+            'title' => ts('Event Type'),
+          ),
+          'event_start_date' => array(
+            'title' => ts('Event Start Date'),
+          ),
+          'event_end_date' => array(
+            'title' => ts('Event End Date'),
+          ),
         ),
         'grouping' => 'event-fields',
         'filters' => array(
@@ -294,6 +298,10 @@ class CRM_Report_Form_Event_ParticipantListing extends CRM_Report_Form_Event {
             'title' => ts('Event Start Date'),
             'operatorType' => CRM_Report_Form::OP_DATE,
           ),
+          'event_end_date' => array(
+            'title' => ts('Event End Date'),
+            'operatorType' => CRM_Report_Form::OP_DATE,
+          ),
         ),
         'order_bys' => array(
           'event_type_id' => array(
@@ -335,7 +343,7 @@ class CRM_Report_Form_Event_ParticipantListing extends CRM_Report_Form_Event {
         'grouping' => 'contrib-fields',
         'filters' => array(
           'receive_date' => array(
-            'title' => 'Payment Date',
+            'title' => ts('Payment Date'),
             'operatorType' => CRM_Report_Form::OP_DATE,
           ),
           'financial_type_id' => array(
@@ -389,7 +397,7 @@ class CRM_Report_Form_Event_ParticipantListing extends CRM_Report_Form_Event {
         'title' => ts('Blank column at the End'),
         'type' => 'select',
         'options' => array(
-          '' => '-select-',
+          '' => ts('-select-'),
           1 => ts('One'),
           2 => ts('Two'),
           3 => ts('Three'),
@@ -500,6 +508,7 @@ ORDER BY  cv.label
       }
     }
 
+    $this->_selectClauses = $select;
     $this->_select = "SELECT " . implode(', ', $select) . " ";
   }
 
@@ -628,7 +637,7 @@ ORDER BY  cv.label
   }
 
   public function groupBy() {
-    $this->_groupBy = "GROUP BY {$this->_aliases['civicrm_participant']}.id";
+    $this->_groupBy = CRM_Contact_BAO_Query::getGroupByFromSelectColumns($this->_selectClauses, "{$this->_aliases['civicrm_participant']}.id");
   }
 
   public function postProcess() {
