@@ -29,8 +29,6 @@
  *
  * @package CRM
  * @copyright CiviCRM LLC (c) 2004-2016
- * $Id$
- *
  */
 class CRM_Report_Form_Event_Summary extends CRM_Report_Form_Event {
 
@@ -50,8 +48,7 @@ class CRM_Report_Form_Event_Summary extends CRM_Report_Form_Event {
   public $_drilldownReport = array('event/income' => 'Link to Detail Report');
 
   /**
-   */
-  /**
+   * Class constructor.
    */
   public function __construct() {
 
@@ -96,11 +93,11 @@ class CRM_Report_Form_Event_Summary extends CRM_Report_Form_Event {
             'options' => CRM_Core_OptionGroup::values('event_type'),
           ),
           'event_start_date' => array(
-            'title' => 'Event Start Date',
+            'title' => ts('Event Start Date'),
             'operatorType' => CRM_Report_Form::OP_DATE,
           ),
           'event_end_date' => array(
-            'title' => 'Event End Date',
+            'title' => ts('Event End Date'),
             'operatorType' => CRM_Report_Form::OP_DATE,
           ),
         ),
@@ -128,6 +125,7 @@ class CRM_Report_Form_Event_Summary extends CRM_Report_Form_Event {
       }
     }
 
+    $this->_selectClauses = $select;
     $this->_select = 'SELECT ' . implode(', ', $select);
   }
 
@@ -179,7 +177,7 @@ class CRM_Report_Form_Event_Summary extends CRM_Report_Form_Event {
 
   public function groupBy() {
     $this->assign('chartSupported', TRUE);
-    $this->_groupBy = " GROUP BY {$this->_aliases['civicrm_event']}.id";
+    $this->_groupBy = CRM_Contact_BAO_Query::getGroupByFromSelectColumns($this->_selectClauses, "{$this->_aliases['civicrm_event']}.id");
   }
 
   /**
@@ -204,7 +202,8 @@ class CRM_Report_Form_Event_Summary extends CRM_Report_Form_Event {
                   $this->_participantWhere
 
         GROUP BY civicrm_participant.event_id,
-                 civicrm_participant.status_id";
+                 civicrm_participant.status_id,
+                 civicrm_participant.fee_currency";
 
     $info = CRM_Core_DAO::executeQuery($sql);
     $participant_data = $participant_info = $currency = array();
@@ -281,7 +280,7 @@ class CRM_Report_Form_Event_Summary extends CRM_Report_Form_Event {
       'type' => CRM_Utils_Type::T_INT,
     );
     $this->_columnHeaders['totalAmount'] = array(
-      'title' => 'Total Income',
+      'title' => ts('Total Income'),
       'type' => CRM_Utils_Type::T_STRING,
     );
   }
