@@ -29,8 +29,6 @@
  *
  * @package CRM
  * @copyright CiviCRM LLC (c) 2004-2016
- * $Id$
- *
  */
 class CRM_Report_Form_Grant_Statistics extends CRM_Report_Form {
 
@@ -41,8 +39,7 @@ class CRM_Report_Form_Grant_Statistics extends CRM_Report_Form {
   protected $_add2groupSupported = FALSE;
 
   /**
-   */
-  /**
+   * Class constructor.
    */
   public function __construct() {
     $this->_columns = array(
@@ -234,6 +231,7 @@ class CRM_Report_Form_Grant_Statistics extends CRM_Report_Form {
         }
       }
     }
+    $this->_selectClauses = $select;
 
     $this->_select = "SELECT " . implode(', ', $select) . " ";
   }
@@ -318,14 +316,14 @@ WHERE {$this->_aliases['civicrm_grant']}.amount_total IS NOT NULL
         if (array_key_exists('fields', $table)) {
           foreach ($table['fields'] as $fieldName => $field) {
             if (!empty($this->_params['fields'][$fieldName])) {
-              $this->_groupBy[] = $field['dbAlias'];
+              $groupBy[] = $field['dbAlias'];
             }
           }
         }
       }
     }
-    if (!empty($this->_groupBy)) {
-      $this->_groupBy = " GROUP BY " . implode(', ', $this->_groupBy);
+    if (!empty($groupBy)) {
+      $this->_groupBy = CRM_Contact_BAO_Query::getGroupByFromSelectColumns($this->_selectClauses, $groupBy);
     }
   }
 
