@@ -47,6 +47,19 @@ class CRM_Report_Form_Member_Detail extends CRM_Report_Form {
   protected $_customGroupExtends = array('Membership', 'Contribution');
   protected $_customGroupGroupBy = FALSE;
 
+  /**
+   * This report has not been optimised for group filtering.
+   *
+   * The functionality for group filtering has been improved but not
+   * all reports have been adjusted to take care of it. This report has not
+   * and will run an inefficient query until fixed.
+   *
+   * CRM-19170
+   *
+   * @var bool
+   */
+  protected $groupFilterNotOptimised = TRUE;
+
   /**
    * Class constructor.
    */
@@ -86,7 +99,7 @@ class CRM_Report_Form_Member_Detail extends CRM_Report_Form {
         'dao' => 'CRM_Member_DAO_Membership',
         'fields' => array(
           'membership_type_id' => array(
-            'title' => 'Membership Type',
+            'title' => ts('Membership Type'),
             'required' => TRUE,
             'no_repeat' => TRUE,
           ),
@@ -102,7 +115,7 @@ class CRM_Report_Form_Member_Detail extends CRM_Report_Form {
             'title' => ts('Join Date'),
             'default' => TRUE,
           ),
-          'source' => array('title' => 'Source'),
+          'source' => array('title' => ts('Source')),
         ),
         'filters' => array(
           'join_date' => array('operatorType' => CRM_Report_Form::OP_DATE),
@@ -206,7 +219,7 @@ class CRM_Report_Form_Member_Detail extends CRM_Report_Form {
             'type' => CRM_Utils_Type::T_INT,
           ),
           'currency' => array(
-            'title' => 'Currency',
+            'title' => ts('Currency'),
             'operatorType' => CRM_Report_Form::OP_MULTISELECT,
             'options' => CRM_Core_OptionGroup::values('currencies_enabled'),
             'default' => NULL,
@@ -288,6 +301,7 @@ class CRM_Report_Form_Member_Detail extends CRM_Report_Form {
       }
     }
 
+    $this->_selectClauses = $select;
     $this->_select = "SELECT " . implode(', ', $select) . " ";
   }
 
