@@ -30,7 +30,6 @@
  * information about it. It needs to extend CRM_Core_Component_Info
  * abstract class.
  *
- * @package CRM
  * @copyright CiviCRM LLC (c) 2004-2016
  * $Id$
  *
@@ -51,9 +50,6 @@ class CRM_Report_Info extends CRM_Core_Component_Info {
    * @return array
    *   collection of required component settings
    */
-  /**
-   * @return array
-   */
   public function getInfo() {
     return array(
       'name' => 'CiviReport',
@@ -91,6 +87,10 @@ class CRM_Report_Info extends CRM_Core_Component_Info {
         ts('access Report Criteria'),
         ts('Change report search criteria'),
       ),
+      'administer private reports' => array(
+        ts('administer private reports'),
+        ts('Edit all private reports'),
+      ),
       'administer reserved reports' => array(
         ts('administer reserved reports'),
         ts('Edit all reports that have been marked as reserved'),
@@ -124,9 +124,6 @@ class CRM_Report_Info extends CRM_Core_Component_Info {
    *   collection of required dashboard settings,
    *                    null if no element offered
    */
-  /**
-   * @return array|null
-   */
   public function getUserDashboardElement() {
     // no dashboard element for this component
     return NULL;
